***************************************************************************
**** Multidimensional Poverty Measure *************************************
**** OPHI-HDCA Summer School 2011 *****************************************
**** 24 August to 3 September 2011 - Delft, the Netherlands ***************
***************************************************************************

* REMEMBER: if you do not want to run a line from the do file, just put * before the line

clear
set more off
set maxvar 10000
set mem 500m
cap log close

*** Replace here your path to the dataset***
cd "C:\my_files\Summer School\2011\Exercises"

*** Replace here the name of your dataset***
log using M0_dofile.txt, text replace
use "XXXX.dta", clear

*** Change weight according to DHS specifications 
replace weight=weight/1000000  

*********************************************************************************
******* Define the deprivation  matrix   ****************************************
*********************************************************************************

*** The dataset can be interpreted as the matrix of achivemnts 
*** We will now crate the deprivation matrix based on the indicator definition; and deprivation cut-off defined by you
*** during the last working session on the normative Issues in Multidimensional Poverty Measure
*** In order to do this, we will generate a new variable for each indicator contained in our measure
*** This will identify with 0 individuals or households who are not deprived in the specific indicator
*** and identify with 1 individual deprived in the specific indicator.
*** Note that you will need to replace with dot "." if the information is missing or inconsistent. 
*** We will assess later the frequency of missing values.


** Example (from Bhutan)
** DEPRIVED IN DRINKING WATER 
** (the individual -HH- is considered deprived in drinking water is: unprotected well, spring, river/lake/pond or other)

lookfor water
codebook b2q12, tab(20)
gen d_dwater=(b2q12==5 | b2q12==6 | b2q12==7 | b2q12==8)
replace d_dwater=. if b2q12==.
tab b2q12 d_dwater [aw=weight], miss
label variable d_dwater "Deprived in drinking water"ic

** Please follow the same logic for all indicators. 
** Note that for advance indicator you may have to use more complex algorithms

*****************************************************************************
********  Create a local variable with all your indicators          *********
*****************************************************************************

local varlist_pov **write here your list of indicators ***

*****************************************************************************
****            Define the weights              *****************************
*****************************************************************************
** Create a loop for the variables with the same weight *********************
*****************************************************************************

foreach var in [write names of variable with same weight]{
local w_`var'=[define weight]
}

foreach var in [write names of variable with same weight]{
local w_`var'=[define weight]
}

*******************************************************************
*********     Define the weigthed deprivation g0* matrix       ****
*******************************************************************

foreach var in  `varlist_pov'{
	gen wg0_`var'= `var'*w_`var'
}

******************************************************************************
*********** Compute the frequency of missing values for indicator ************
******************************************************************************

foreach var in `varlist_pov' {
gen `var'_miss=1 if `var'==.
replace `var'_miss=0 if `var'!=.
}

sum *_miss


********************************************************************************
*************   Define the (weighted) deprivation count vector "ci" ************
********************************************************************************

egen ci=rsum(wg0_*)
label variable ci "Deprivation Count"

egen n_missing=rowmiss(wg0_*)
label variable n_missing "Number of missing variables by individual"
gen missing=(n_missing>0)
label variable missing "Individual with missing variables"

*** Check sample drop due to missing values
tab missing

*******************************************************************************
***** Create de identification vector (poor/non poor) *************************
***** and compute individual average of deprivation ***************************
*******************************************************************************

forvalues x=1(1)10 {
gen h_`x'0p=(ci>=`x'/10) 
replace h_`x'0p=. if missing==1
gen a_`x'0p=(ci) if h_`x'0p==1
replace a_`x'0p=. if missing==1
label var h_`x'0p "Condition of Multidimensional Poverty  k=`x'"
label var a_`x'0p "Individual Average deprivation  k=`x'"
}

summarize h* a* [aw=weight]

********************************************************************************
******* Compute raw headcounts        ******************************************
********************************************************************************

foreach var in `varlist_pov' {
gen `var'_raw=(`var')
replace `var'_raw=. if missing==1
}

su *_raw  [iw=weight]

******************************************************************************
*********** Compute Censored headcount and censored headocunt ****************
******************************************************************************
***** Please define in the first line your poverty cutoff, the example shows k=20 is 20%

local k=20
foreach var in `varlist_pov' {
gen `var'_CH_`k'=(`var'==1 & h_`k'==1)
replace `var'_CH_`k'=. if missing==1
}

summarize *_CH_`k' [iw=weight]

collapse h* a*  *_CH_* *_raw [iw=weight]  /* ,by(region) */

forvalues x=1(1)10 {
gen M0_`x'0p=h_`x'0p*a_`x'0p
replace  M0_`x'0p=. if missing==1
}






